CherryMusic

### About CherryMusic

CherryMusic was created by Tom Wallroth and is currently developed together with Tilman Börner.

Visit the CherryMusic website or get the source-code directly from github

thanks to

- The CherryPy team for a great application server
- HappyWorm for the HTML5 audio playback
- Christian Maximilian Blasius for the idea for the logo!
- Bootstrap for the nice look'n'feel of the UI
- 6arms1leg for maintaining the package for Arch Linux
- Adrian Sampson for audioread

CherryMusic © 2012–2014

version

### Options

### keyboard shortcuts

next track |  | change
stop |  | change
previous track |  | change
pause | space | change
play |  | change
search |  | change

### misc

Autoplay when adding first track
Confirm closing if music is playing
Display album art when playing
Limit audio bitrate
kbps

### change password

change password

### export playlists

create archive

### change password

old password
new password
repeat new password
confirm password change

### create playlist archive

Playlist file format:
m3u
pls
include other people's public playlists
export playlists as ZIP file

### change album art

for folder

Search for art:
search

### Options

#### Create new user:

User Name
Password
admin

#### User List:

#### Advanced:

Update Music Library (may take some time!)
Enable JPlayer Debugging

### Save new playlist

Playlist title
visible for other users

### Delete playlist

Do you really want to delete this precious playlist?

random! save as playlist
download